@@ -1,14 +1,15 @@
+import logging
 
-from .security.manager import SecurityManager
-    
 from .views import IndexView
 from filters import TemplateFilters
 from flask import Blueprint
 from flask.ext.babelpkg import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
 from flask.ext.appbuilder import translations
+from .security.manager import SecurityManager
 from menu import Menu
 
+log = logging.getLogger(__name__)
 
 class BaseApp(object):
     """
@@ -23,7 +24,7 @@ class BaseApp(object):
             baseapp = BaseApp(app, db)
         
     """
-    lst_baseview = []
+    baseviews = []
     app = None
     db = None
     
@@ -135,7 +136,7 @@ class BaseApp(object):
         try:
             self.sm.add_permissions_menu(name)
         except:
-            print "Add Permission on Menu Error: DB not created"
+            log.error("Add Permission on Menu Error")
     
     
     def _add_menu_permissions(self):
@@ -169,10 +170,11 @@ class BaseApp(object):
                 # Add a link
                 baseapp.add_link("google", href="www.google.com", icon = "fa-google-plus")
         """
-        print "Registering:", category,".", name
-        if baseview not in self.lst_baseview:
+        log.info("Registering class %s on menu %s.%s" % (baseview.__class__.__name__, category,name))
+        if baseview not in self.baseviews:
             baseview.baseapp = self
-            self.lst_baseview.append(baseview)
+            self.baseviews.append(baseview)
+            self._process_ref_related_views()
             self.register_blueprint(baseview)
             self._add_permission(baseview)
         self.add_link(name = name, href = href, icon = icon, category = category, baseview = baseview)
@@ -213,9 +215,10 @@ class BaseApp(object):
                 A BaseView type class instantiated.
                     
         """
-        if baseview not in self.lst_baseview:
+        if baseview not in self.baseviews:
             baseview.baseapp = self
-            self.lst_baseview.append(baseview)
+            self.baseviews.append(baseview)
+            self._process_ref_related_views()
             self.register_blueprint(baseview, endpoint = endpoint, static_folder = static_folder)
             self._add_permission(baseview)
 
@@ -223,7 +226,19 @@ class BaseApp(object):
         try:
             self.sm.add_permissions_view(baseview.base_permissions, baseview.__class__.__name__)
         except:
-            print "Add Permission on View Error: DB not created?"
+            log.error("Add Permission on View Error")
         
     def register_blueprint(self, baseview, endpoint = None, static_folder = None):
         self.app.register_blueprint(baseview.create_blueprint(self,  endpoint = endpoint, static_folder = static_folder))
+
+    def _process_ref_related_views(self):
+        try:
+            for view in self.baseviews:
+                if hasattr(view, 'related_views'):
+                    for rel_class in view.related_views:
+                        for v in self.baseviews:
+                            if isinstance(v, rel_class) and v not in view._related_views:
+                                view._related_views.append(v)
+        except:
+            raise Exception('Use related_views with classes, not instances')
+        
